@@ -27,10 +27,6 @@ class UserProfileInline(admin.StackedInline):
     filter_horizontal = ('roles',)
 
 
-class FilterInline(admin.StackedInline):
-    model = models.Filter
-
-
 class UserProfileAdmin(UserAdmin):
     add_fieldsets = (
         (None, {
@@ -42,7 +38,7 @@ class UserProfileAdmin(UserAdmin):
             )
         }),
     )
-    inlines = [UserProfileInline, FilterInline, ]
+    inlines = [UserProfileInline]
 
     def get_actions(self, request):
         actions = super(UserProfileAdmin, self).get_actions(request)
@@ -63,6 +59,23 @@ class UserProfileAdmin(UserAdmin):
                 return False
         return True
 
+    def save_formset(self, request, form, formset, change):
+        """
+        The user profile is already created by a signal so
+        attatch the existing user profile if after the user
+        has been saved.
+        """
+        if change:
+            super().save_formset(request, form, formset, change)
+        else:
+            instances = formset.save(commit=False)
+            profile = UserProfile.objects.get(user_id=form.instance.id)
+            for i in instances:
+                i.id = profile.id
+                i.user = profile.user
+                i.save()
+            formset.save_m2m()
+
 
 class MyAdmin(VersionAdmin):
     pass
@@ -191,4 +204,3 @@ for subclass in episode_subrecords():
 
 admin.site.register(models.ContactNumber, MyAdmin)
 admin.site.register(models.Role, MyAdmin)
-admin.site.register(models.Macro, MyAdmin)
