@@ -1,40 +1,5 @@
 var filters = angular.module('opal.filters', []);
 
-filters.filter('microresult', function() {
-	return function(input) {
-		if (input == 'positive') {
-			return 'POS';
-		} else if (input == 'negative') {
-			return 'NEG';
-		} else if (input == 'equivocal') {
-			return 'EQUIV';
-		} else {
-			return input;
-		};
-	};
-});
-
-filters.filter('boxed',  function(){
-    return function(input){
-        if(input == true){
-            return '[X]'
-        }
-        return '[ ]'
-    }
-})
-
-filters.filter('plural', function(){
-		return function(someWord, count, plural){
-				if(count === 1){
-					 return someWord;
-				}
-				else if(plural){
-					 return plural;
-				}
-				return someWord + "s";
-		};
-});
-
 filters.filter('toMoment', function(){
 		return function(input){
 			if(!input){
