@@ -1,6 +1,6 @@
 
 angular.module('opal.services')
     .factory('EpisodeResource', function($resource, $q) {
-        resource = $resource('/episode/:id/', {id: '@id'});
+        resource = $resource('/api/v0.1/episode/:id/', {id: '@id'});
         return resource
     });
