@@ -3,7 +3,7 @@ Unittests for opal.models
 """
 import os
 import datetime
-from mock import patch, MagicMock
+from mock import patch
 
 from django.conf import settings
 from django.utils import timezone
@@ -77,11 +77,6 @@ class PatientTestCase(OpalTestCase):
             episode.category_name
         )
 
-    def test_create_episode_category(self):
-        patient = models.Patient.objects.create()
-        e = patient.create_episode(category_name='Outpatient')
-        self.assertEqual('Outpatient', e.category_name)
-
     def test_bulk_update_patient_subrecords(self):
         original_patient = models.Patient()
 
@@ -428,8 +423,8 @@ class SubrecordTestCase(OpalTestCase):
         self.assertEqual(hats, "Hats")
 
     def test_get_title_over_reverse_foreign_key(self):
-        hats = HouseOwner._get_field_title("house")
-        self.assertEqual(hats, "Houses")
+        houses = HouseOwner._get_field_title("house")
+        self.assertEqual(houses, "Houses")
 
     def test_verbose_name(self):
         only_words = FamousLastWords._get_field_title("words")
@@ -463,6 +458,10 @@ class SubrecordTestCase(OpalTestCase):
     def test_get_defaults_from_free_text_and_foreign_key_lambda(self):
         self.assertEqual("spaniel", HoundOwner._get_field_default("dog"))
 
+    def test_get_defaults_from_reverse_foreign_key(self):
+        houses = HouseOwner._get_field_default("house")
+        self.assertEqual([], houses)
+
     def test_get_defaults_from_ftfk_when_there_are_no_defaults(self):
         self.assertEqual(None, Colour._get_field_default("name"))
 
@@ -843,13 +842,6 @@ class SynonymTestCase(OpalTestCase):
         self.assertEqual('Name', s.__str__())
 
 
-class MacroTestCase(OpalTestCase):
-
-    def test_str(self):
-        m = models.Macro(title='My Macro')
-        self.assertEqual('My Macro', m.__str__())
-
-
 class RoleTestCase(OpalTestCase):
 
     def test_str(self):
@@ -860,4 +852,4 @@ class RoleTestCase(OpalTestCase):
 class UserProfileTestCase(OpalTestCase):
     def test_create(self):
         user = User.objects.create()
-        self.assertTrue(bool(user.profile))
\ No newline at end of file
+        self.assertTrue(bool(user.profile))
